@@ -3,6 +3,7 @@ from enum import Enum
 
 
 class DDKChannelType1(Enum):
+    """推荐商品的频道"""
     TODAY_HOT_SALES = 1  # 今日热销榜
     SIMILAR_GOODS = 3  # 相似商品推荐
     GUESS_U_LIKE = 4  # 猜你喜欢(和进宝网站精选一致)
@@ -11,6 +12,7 @@ class DDKChannelType1(Enum):
 
 
 class DDKChannelType2(Enum):
+    """营销推广渠道"""
     ACTIVITY_LIST = 1  # 活动列表
     RED_PACKET = 0  # 红包(需申请推广权限)
     FRESH_RED_PACKET = 2  # 新人红包
@@ -29,6 +31,7 @@ class DDKChannelType2(Enum):
 
 
 class DDKChannelType3(Enum):
+    """商城-频道推广渠道"""
     # 1.9包邮
     ONE_NINE = 0
     # 今日爆款
