@@ -2,6 +2,7 @@
 import aiohttp as aiohttp
 
 from itle.base import RestApi
+from itle.ddk.ddk_resource_type import DDKResourceType
 
 
 class DDKResourceUrlRequest(RestApi):
@@ -11,7 +12,7 @@ class DDKResourceUrlRequest(RestApi):
         self.ddk_pid = None
         self.custom_params = None
         self.url = None
-        self.resource_type = None
+        self.resource_type = DDKResourceType.BILLIONS_SUBSIDE.value
 
     def get_api_uri(self):
         return '/api/1.0/ddk/resource_url'
